==> cutefish-core_0.4.orig.tar.gz: core-0.4/settings-daemon/translations/bg_BG.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg" sourcelanguage="de_DE">
<context>
    <name>Battery</name>
    <message>
        <source>d</source>
        <translation type="vanished">Tage</translation>
    </message>
    <message>
        <source>h</source>
        <translation type="vanished">Stunden</translation>
    </message>
    <message>
        <source>m</source>
        <translation type="vanished">Minuten</translation>
    </message>
    <message>
        <source>until fully charged.</source>
        <translation type="vanished">bis Akku voll.</translation>
    </message>
    <message>
        <source>remaining.</source>
        <translation type="vanished">übrig.</translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="268"/>
        <source>%1d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="274"/>
        <source>%1h</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="281"/>
        <source>%1m</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="290"/>
        <source>%1 until fully charged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="292"/>
        <source>%1 remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="294"/>
        <source>Fully charged.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="317"/>
        <source>now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="319"/>
        <source>%1 ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ago</source>
        <translation type="vanished">vergangen</translation>
    </message>
</context>
<context>
    <name>UPowerDevice</name>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="71"/>
        <source>%1 Battery</source>
        <comment>%1 is battery technology</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="87"/>
        <source>Lithium-ion</source>
        <comment>battery technology</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="89"/>
        <source>Lithium Polymer</source>
        <comment>battery technology</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="91"/>
        <source>Lithium Iron Phosphate</source>
        <comment>battery technology</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="93"/>
        <source>Lead Acid</source>
        <comment>battery technology</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="95"/>
        <source>Nickel Cadmium</source>
        <comment>battery technology</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="97"/>
        <source>Nickel Metal Hydride</source>
        <comment>battery technology</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="99"/>
        <source>Unknown</source>
        <comment>battery technology</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> cutefish-core_0.8.orig.tar.gz: core-0.8/settings-daemon/translations/bg_BG.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg" sourcelanguage="de_DE">
<context>
    <name>Battery</name>
    <message>
        <source>d</source>
        <translation type="vanished">Tage</translation>
    </message>
    <message>
        <source>h</source>
        <translation type="vanished">Stunden</translation>
    </message>
    <message>
        <source>m</source>
        <translation type="vanished">Minuten</translation>
    </message>
    <message>
        <source>until fully charged.</source>
        <translation type="vanished">bis Akku voll.</translation>
    </message>
    <message>
        <source>remaining.</source>
        <translation type="vanished">übrig.</translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="268"/>
        <source>%1d</source>
        <translation>%1d</translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="274"/>
        <source>%1h</source>
        <translation>%1h</translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="281"/>
        <source>%1m</source>
        <translation>%1m</translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="290"/>
        <source>%1 until fully charged</source>
        <translation>%1 до пълно зареждане</translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="292"/>
        <source>%1 remaining</source>
        <translation>Остават %1</translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="294"/>
        <source>Fully charged.</source>
        <translation>Напълно заредена.</translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="317"/>
        <source>now</source>
        <translation>сега</translation>
    </message>
    <message>
        <location filename="../battery/battery.cpp" line="319"/>
        <source>%1 ago</source>
        <translation>Преди %1</translation>
    </message>
    <message>
        <source>ago</source>
        <translation type="vanished">vergangen</translation>
    </message>
</context>
<context>
    <name>UPowerDevice</name>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="71"/>
        <source>%1 Battery</source>
        <comment>%1 is battery technology</comment>
        <translation>%1 Батерия</translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="87"/>
        <source>Lithium-ion</source>
        <comment>battery technology</comment>
        <translation>Литиево-йонна</translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="89"/>
        <source>Lithium Polymer</source>
        <comment>battery technology</comment>
        <translation>Литиево-полимерна</translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="91"/>
        <source>Lithium Iron Phosphate</source>
        <comment>battery technology</comment>
        <translation>Литиев железен фосфат</translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="93"/>
        <source>Lead Acid</source>
        <comment>battery technology</comment>
        <translation>Оловна киселина</translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="95"/>
        <source>Nickel Cadmium</source>
        <comment>battery technology</comment>
        <translation>Никел кадмий</translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="97"/>
        <source>Nickel Metal Hydride</source>
        <comment>battery technology</comment>
        <translation>Никел метал хидрид</translation>
    </message>
    <message>
        <location filename="../battery/upowerdevice.cpp" line="99"/>
        <source>Unknown</source>
        <comment>battery technology</comment>
        <translation>Неизвестна</translation>
    </message>
</context>
</TS>
